==> savane-1.0.1.tar.gz: savane/frontend/php/help/browse_bug_sort.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: browse_bug_sort.php,v 1.5 2004/01/31 00:56:18 yeupou Exp $
//
//
// CodeX: Breaking Down the Barriers to Source Code Sharing inside Xerox
// Copyright (c) Xerox Corporation, CodeX / CodeX Team, 2001-2002. All Rights Reserved
// http://codex.xerox.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//	Originally written by Laurent Julliard 2001, 2002, CodeX Team, Xerox
//

require "../include/pre.php";

help_header("Bug Search -  Sorting results", true, $sys_themedefault);

?>

<p>The Bug Tracking System (BTS) offers a rich set of features to help
you sort your bug selection in the most convenient way.

<h3>Basic Sort</h3>

To sort your bug report according to a given criteria simply click on the
corresponding column heading in the bug table. Clicking twice on the same
column will change the sorting direction from ascending to descending and
vice-versa. The sorting direction is shown by a small up 
(<img src="/images/up_arrow.png" border="0">) or 
down (<img src="/images/dn_arrow.png" border="0">) arrow 
 next to the sort criteria.

<h3>Mutli-column Sort</h3>

For more sophisticated processing you can also activate the multi-column sort.
 In this mode sort criteria cumulates as you click on column headings. 
So you can for instance click 'Severity' first and 'Assigned To' second to 
see who in the team is assigned critical bugs and how many.

<p>Also notice that At any point in the multi-column sort process, a
click on one of the sort criteria displayed in the list (criteria 1 >
criteria 2 > criteria 3...)  will bring you back in the sort criteria
list. Using this feature you can easily test various sorting
strategies.

<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: browse_bug_sort.php,v 1.5 2004/01/31 00:56:18 yeupou Exp $
//
help_footer();
?>

==> savane-1.0.2.tar.gz: savane/frontend/php/help/browse_bug_sort.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: browse_bug_sort.php,v 1.6 2004/03/13 18:22:05 yeupou Exp $
#
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

help_header("Bug Search -  Sorting results", true, $sys_themedefault);

?>

<p>The Bug Tracking System (BTS) offers a rich set of features to help
you sort your bug selection in the most convenient way.

<h3>Basic Sort</h3>

To sort your bug report according to a given criteria simply click on the
corresponding column heading in the bug table. Clicking twice on the same
column will change the sorting direction from ascending to descending and
vice-versa. The sorting direction is shown by a small up 
(<img src="/images/up_arrow.png" border="0">) or 
down (<img src="/images/dn_arrow.png" border="0">) arrow 
 next to the sort criteria.

<h3>Mutli-column Sort</h3>

For more sophisticated processing you can also activate the multi-column sort.
 In this mode sort criteria cumulates as you click on column headings. 
So you can for instance click 'Severity' first and 'Assigned To' second to 
see who in the team is assigned critical bugs and how many.

<p>Also notice that At any point in the multi-column sort process, a
click on one of the sort criteria displayed in the list (criteria 1 >
criteria 2 > criteria 3...)  will bring you back in the sort criteria
list. Using this feature you can easily test various sorting
strategies.

<?php

help_footer();
?>
